@@ -1,7 +1,7 @@
 from ._version import __version__
 from .classifier import Classifier, ClassifierCategory
 from .datatype import DataType
-from .fileset import FileSet
+from .fileset import FileSet, MockMixin
 from .field import Field
 from .utils import (
     to_mime,
