@@ -2,7 +2,7 @@ from pathlib import Path
 import re
 import typing as ty
 from collections import defaultdict
-from . import mark
+from . import hook
 from .fileset import FileSet
 from .utils import classproperty, describe_task, to_mime_format_name
 from .converter import SubtypeVar
@@ -30,7 +30,7 @@ class WithMagicNumber:
     binary: bool
     magic_number: ty.Union[str, bytes]
 
-    @mark.check
+    @hook.check
     def check_magic_number(self):
         if self.binary and isinstance(self.magic_number, str):
             magic_bytes = bytes.fromhex(self.magic_number)
@@ -74,7 +74,7 @@ class WithMagicVersion:
     magic_pattern_offset = 0
     magic_pattern_maxlength = None
 
-    @mark.required
+    @hook.required
     @property
     def version(self) -> ty.Union[str, ty.Tuple[str]]:
         read_length = (
@@ -169,7 +169,7 @@ class WithSeparateHeader(WithAdjacentFiles):
     def nested_types(cls):
         return (cls.header_type,)
 
-    @mark.required
+    @hook.required
     @property
     def header(self):
         return self.header_type(self.select_by_ext(self.header_type))
@@ -200,7 +200,7 @@ class WithSideCars(WithAdjacentFiles):
         the file-formats of the expected side-car files
     """
 
-    @mark.required
+    @hook.required
     @property
     def side_cars(self):
         return [tp(self.select_by_ext(tp)) for tp in self.side_car_types]
@@ -555,7 +555,7 @@ class WithClassifiers:
         source_format: type,
         converter_tuple: ty.Tuple[ty.Callable, ty.Dict[str, ty.Any]],
     ):
-        """Registers a converter task within a class attribute. Called by the @fileformats.mark.converter
+        """Registers a converter task within a class attribute. Called by the @fileformats.hook.converter
         decorator.
 
         Parameters
