@@ -1,12 +1,18 @@
-import attrs
+"""Adds support for "field" data types
+
+While not "file-formats", in some workflows, particularly when interacting with a data
+store such as in Arcana, it is useful to interchangeably interact with file and field
+data, so the classes in this module are provided to support these use cases.
+"""
 import decimal
-from ..core import Field
-from ..core.mixin import WithQualifiers
-from ..core.exceptions import FormatMismatchError
+import typing as ty
+import attrs
+from fileformats.core import Field
+from fileformats.core.mixin import WithClassifiers
+from fileformats.core.exceptions import FormatMismatchError
 
 
-@attrs.define
-class Singluar(Field):
+class Singular(Field):
     pass
 
 
@@ -63,7 +69,7 @@ def text_converter(value):
     try:
         return str(value)
     except ValueError as e:
-        raise FormatMismatchError(str(e))
+        raise FormatMismatchError(str(e)) from None
 
 
 def integer_converter(value):
@@ -75,7 +81,7 @@ def integer_converter(value):
     try:
         return int(value)
     except ValueError as e:
-        raise FormatMismatchError(str(e))
+        raise FormatMismatchError(str(e)) from None
 
 
 def decimal_converter(value):
@@ -84,7 +90,7 @@ def decimal_converter(value):
     try:
         return decimal.Decimal(value)
     except decimal.InvalidOperation as e:
-        raise FormatMismatchError(str(e))
+        raise FormatMismatchError(str(e)) from None
 
 
 def boolean_converter(value):
@@ -101,39 +107,50 @@ def boolean_converter(value):
         try:
             value = bool(value)
         except ValueError as e:
-            raise FormatMismatchError(str(e))
+            raise FormatMismatchError(str(e)) from None
     return value
 
 
 def array_converter(value):
     if isinstance(value, str):
-        if value.startswith("[") and value.endswith("]"):
+        if (value.startswith("[") and value.endswith("]")) or (
+            value.startswith("(") and value.endswith(")")
+        ):
             value = value[1:-1]
-        elif value.startswith("[") or value.endswith("]"):
+        elif (
+            value.startswith("[")
+            or value.endswith("]")
+            or value.startswith("(")
+            or value.endswith(")")
+        ):
             raise FormatMismatchError(f"Unmatched brackets in array field {value}")
-        value = [v.strip() for v in value.split(",")]
+        value = tuple(v.strip() for v in value.split(","))
     else:
         try:
-            value = list(value)
+            value = tuple(value)
         except ValueError as e:
-            raise FormatMismatchError(str(e))
+            raise FormatMismatchError(str(e)) from None
     return value
 
 
-@attrs.define
-class Text(Singluar):
-
+@attrs.define(repr=False)
+class Text(Singular):
     value: str = attrs.field(converter=text_converter)
 
-    raw_type = str
+    primitive = str
+
+    def __hash__(self):
+        return hash(self.value)
+
+    def __repr__(self):
+        return f'{self.type_name}("{self.value}")'
 
 
-@attrs.define
-class Integer(Singluar, ScalarMixin):
-
+@attrs.define(repr=False)
+class Integer(Singular, ScalarMixin):
     value: int = attrs.field(converter=integer_converter)
 
-    raw_type = int
+    primitive = int
 
     def __int__(self):
         return self.value
@@ -144,13 +161,15 @@ class Integer(Singluar, ScalarMixin):
     def __bool__(self):
         return bool(self.value)
 
+    def __hash__(self):
+        return hash(self.value)
 
-@attrs.define
-class Decimal(Singluar, ScalarMixin):
 
+@attrs.define(repr=False)
+class Decimal(Singular, ScalarMixin):
     value: decimal.Decimal = attrs.field(converter=decimal_converter)
 
-    raw_type = float
+    primitive = float
 
     def __float__(self):
         return float(self.value)
@@ -158,11 +177,13 @@ class Decimal(Singluar, ScalarMixin):
     def __bool__(self):
         return bool(self.value)
 
+    def __hash__(self):
+        return hash(self.value)
 
-@attrs.define
-class Boolean(Singluar, LogicalMixin):
 
-    raw_type = bool
+@attrs.define(repr=False)
+class Boolean(Singular, LogicalMixin):
+    primitive = bool
 
     value: bool = attrs.field(converter=boolean_converter)
 
@@ -172,30 +193,34 @@ class Boolean(Singluar, LogicalMixin):
     def __bool__(self):
         return self.value
 
+    def __hash__(self):
+        return hash(self.value)
 
-@attrs.define
-class Array(WithQualifiers, Field):
 
-    # WithQualifiers class attrs
-    qualifiers_attr_name = "item_type"
-    multiple_qualifiers = False
-    allowed_qualifiers = (Singluar,)
-    item_type = None
+@attrs.define(auto_attribs=False, repr=False)
+class Array(WithClassifiers, Field, ty.Sequence):
+    # WithClassifiers class attrs
+    classifiers_attr_name: str = "item_type"
+    multiple_classifiers: bool = False
+    allowed_classifiers: ty.Tuple[ty.Type[Singular]] = (Singular,)
+    item_type: ty.Union[ty.Type[Singular], None] = None
 
-    raw_type = list
+    primitive = tuple
 
-    value: list = attrs.field(converter=array_converter)
+    value: tuple = attrs.field(converter=array_converter)
 
     def __attrs_post_init__(self):
         # Ensure items are of the correct type
         if self.item_type is not None:
-            self.value = [self.item_type(i).value for i in self.value]
+            self.value = tuple(self.item_type(i).value for i in self.value)
 
     def __str__(self):
         return (
             "["
             + ",".join(
-                str(self.item_type(i)) if self.item_type is not None else i
+                str(self.item_type(i))
+                if self.item_type is not None
+                else i  # pylint: disable=not-callable
                 for i in self.value
             )
             + "]"
@@ -203,3 +228,12 @@ class Array(WithQualifiers, Field):
 
     def __iter__(self):
         return iter(self.value)
+
+    def __hash__(self):
+        return hash(self.value)
+
+    def __len__(self):
+        return len(self.value)
+
+    def __getitem__(self, index):
+        return self.value[index]
